.. _ref-API-File:

File class
==========

A file is either a Blosc2 dataset or a regular file on a root repository.

.. currentmodule:: caterva2
.. autosummary::
    :toctree: autofiles

    File.__init__
    File.__getitem__
    File.get_download_url
    File.download
    File.remove
    File.move
    File.copy
    File.vlmeta
